# gpu_task.py
import torch
import ray

# Initialize Ray (it will automatically connect if you are using Ray Job Submission)
ray.init()

# Request for 1 GPU here
@ray.remote(num_gpus=1)
def gpu_task():
    print("Running on GPU" if torch.cuda.is_available() else "No GPU available.")
    
    # Create a tensor and move it to the GPU
    tensor = torch.randn(1000, 1000).to("cuda" if torch.cuda.is_available() else "cpu")
    
    # Perform a simple matrix multiplication on the GPU
    result = torch.matmul(tensor, tensor)
    
    print("Computation finished. Result tensor shape:", result.shape)
    return result.shape

if __name__ == "__main__":
    # Run the remote function that requires a GPU
    future = gpu_task.remote()
    result = ray.get(future)
    print("Result from GPU task:", result)